@@ -62,7 +62,7 @@ static void err_with_errno(const char* syscall, const char* affected_file)
 	err("%s(\"%s\") failed: %s", syscall, affected_file, strerror(errno));
 }
 
-static void err_with_GError(GError* g_error, const char* action, const char* affected_file)
+static void err_with_GError(const GError* g_error, const char* action, const char* affected_file)
 {
 	err("%s(\"%s\") failed: %s", action, affected_file, g_error->message);
 }
@@ -132,7 +132,7 @@ static char** get_zip_content_file_names(const char* zip_file_name)
 	
 	if (!g_spawn_sync(NULL, (char**) argv, NULL, G_SPAWN_STDERR_TO_DEV_NULL, NULL, NULL, &standard_output, NULL, &exit_code, &error)) {
 		/* unzip printed reason to stderr */
-		err_with_GError(error, "could not read zip file", zip_file_name);
+		err_with_GError(error, "could not read ZIP file", zip_file_name);
 		g_error_free(error);
 		return NULL;
 	}
@@ -327,7 +327,7 @@ static int unzip_file(const char* zip_file_name, const char* zip_extraction_dire
 	
 	if (!g_spawn_async(NULL, (char**) argv, NULL, G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_DO_NOT_REAP_CHILD, NULL, NULL, &child_pid, &error)) {
 		/* unzip printed reason to stderr */
-		err_with_GError(error, "unzipping of \"%s\" failed", zip_file_name);
+		err_with_GError(error, "unzipping failed", zip_file_name);
 		g_error_free(error);
 		return -1;
 	}
